acb_games_2223_coach: ACB coaches in the 2022-2023 season.

acb_games_2223_coachR Documentation

ACB coaches in the 2022-2023 season.

Description

Coach for each team in all the games of the ACB 2022-2023 season.

Usage

acb_games_2223_coach

Format

Data frame with 612 rows and 4 columns.

Note

The game_code column allows us to detect the source website, for example, https://live.acb.com/es/partidos/103389/jugadas.

https://www.acb.com/


BAwiR documentation built on Feb. 27, 2026, 5:07 p.m.