| acb_sticker_data_2526 | R Documentation |
This data frame contains an example of the usage and context statistics for the Real Madrid player Alberto Abalde to illustrate the creation of the sticker plot.
acb_sticker_data_2526
Data frame with 11 rows and 9 columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.