acb_usage_act_data_2526: ACB usage action data, 2025-2026

acb_usage_act_data_2526R Documentation

ACB usage action data, 2025-2026

Description

Sample of possessions played and ended for a game from the ACB 2025-2026 season and the particular number of actions used by the player to end the possession.

Usage

acb_usage_act_data_2526

Format

Data frame with 75 rows and 8 columns.

https://www.acb.com/


BAwiR documentation built on Feb. 27, 2026, 5:07 p.m.