acb_usage_data_2526: ACB usage data, 2025-2026

acb_usage_data_2526R Documentation

ACB usage data, 2025-2026

Description

Sample of possessions played and ended for a game from the ACB 2025-2026 season. For each player we have the number of possessions he played and the ones he ended.

Usage

acb_usage_data_2526

Format

Data frame with 62 rows and 9 columns.

https://www.acb.com/


BAwiR documentation built on Feb. 27, 2026, 5:07 p.m.