do_divide_court_zones: Zones of the basketball court

View source: R/do_divide_court_zones.R

do_divide_court_zonesR Documentation

Zones of the basketball court

Description

Divide the basketball court into 10 zones.

Usage

do_divide_court_zones(data_shots)

Arguments

data_shots

Shooting data frame.

Value

The shooting data frame with a new column called "location" indicating the zone from which each shot was taken.

Author(s)

Guillermo Vinue

Examples

## Not run: 
do_divide_court_zones(acb_shooting_data_2425)

## End(Not run)


BAwiR documentation built on Feb. 27, 2026, 5:07 p.m.