View source: R/do_scrape_days_acb.R
| do_scrape_days_acb | R Documentation |
Obtain the game codes of any regular season day from any ACB season. These game codes can be used for example to define the target url from which collecting the shooting data of every game.
do_scrape_days_acb(edition_id)
edition_id |
Identifier of the league edition. For 2026-2027 is 91. For coming seasons, check it at the ACB website. |
A data frame with two columns, one with the day and the other with the game code. For 34 days and 9 games per day, there must be 306 rows.
Before starting the web scraping, we must visit https://www.acb.com/robots.txt to check for permissions.
Guillermo Vinue with help from ChatGPT.
do_scrape_shots_acb
## Not run:
data_days <- do_scrape_days_acb(91)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.