do_time_out_success_altern: Alternative timeouts

View source: R/do_time_out_success_altern.R

do_time_out_success_alternR Documentation

Alternative timeouts

Description

This is an alternative to do_time_out_success from season 2025-2026 because to my best of knowledge the timeouts are not directly collected from web scraping and I have to check manually when they were called.

Usage

do_time_out_success_altern(data, day_num, game_code, team_sel, data_to_list, verbose)

Arguments

data

Prepared data from a given game.

day_num

Day number.

game_code

Game code.

team_sel

One of the teams' names involved in the game.

data_to_list

List with all the timeouts called from all coaches.

verbose

Logical. Decide if information of the computations must be provided or not.

Value

Data frame. This is the meaning of the columns:

day: Day number. game_code: Game code. team: Name of the corresponding team and coach. times_out_requested: Number of timeouts requested in the game. times_out_successful: Number of timeouts that resulted in scoring. times_out_successful_perc: Percentage of successful timeouts. points_scored: Total of points achieved after the timeouts.

Author(s)

Guillermo Vinue

See Also

do_time_out_success


BAwiR documentation built on Feb. 27, 2026, 5:07 p.m.