do_violin_box_plots: Plots of data distributions

View source: R/do_violin_box_plots.R

do_violin_box_plotsR Documentation

Plots of data distributions

Description

Create violin plots and boxplots to analyze the distribution of the two-point, three-point and total shots. Violin plots show the distribution shape, while boxplots give a compact statistical summary.

Usage

do_violin_box_plots(data_shots, data_players)

Arguments

data_shots

Shooting data frame.

data_players

Players' identifiers data frame.

Value

A plot.

Author(s)

Guillermo Vinue

Examples

## Not run: 
df0 <- do_divide_court_zones(acb_shooting_data_2425)

df1 <- do_filter_data(df0, "2024-2025", "", "", "", "", "")

do_violin_box_plots(df1, acb_players_2425)

## End(Not run)


BAwiR documentation built on Feb. 27, 2026, 5:07 p.m.