do_volume_threes: Volume of three-point shots

View source: R/do_volume_threes.R

do_volume_threesR Documentation

Volume of three-point shots

Description

This function computes the three-point shots volume, both in offense in defense. This volume is defined as the percentage of three-point shots attempted with respect to the total field-goal attempts.

Usage

do_volume_threes(df)

Arguments

df

Data frame with the games and the players info.

Value

A data frame with the volume statistics.

Author(s)

Guillermo Vinue

Examples

library(dplyr)

df0 <- do_join_games_bio("ACB", acb_games_1718, acb_players_1718) 

df1 <- df0 %>% rename(game_code = Game)

data_volume <- do_volume_threes(df1)

data_volume$data_volume_threes
data_volume$data_volume_threes_comp
                 

BAwiR documentation built on Feb. 27, 2026, 5:07 p.m.