get_donut_usage: Donut chart usage possessions

View source: R/get_donut_usage.R

get_donut_usageR Documentation

Donut chart usage possessions

Description

This function creates a donut chart that displays the percentage of possessions that each player of a team ends while being on the court.

Usage

get_donut_usage(data_usage, team_sel, size_play, size_perc)

Arguments

data_usage

Data frame with the number of possessions that each player played and the number that he ended.

team_sel

String with the team's full name.

size_play

Size of the players' labels.

size_perc

Size of the percentages labels.

Details

Donut charts are an alternative for pie charts, which have a hole in the middle, making them cleaner to read than pie charts.

Value

A donut chart.

Author(s)

Guillermo Vinue with the help of ChatGPT.

See Also

get_donut_usage_action

Examples

## Not run: 
get_donut_usage(acb_usage_data_2526, "Valencia Basket", 3, 4)

## End(Not run)


BAwiR documentation built on Feb. 27, 2026, 5:07 p.m.