get_roster_age_profile: Roster age profile

View source: R/get_roster_age_profile.R

get_roster_age_profileR Documentation

Roster age profile

Description

For the players of the same team, show their age at time of joining the team, their current year and how many years they have spent in the team.

Usage

get_roster_age_profile(data_age_team, team_sel, language)

Arguments

data_age_team

Data frame with the team's age profile.

team_sel

Team.

language

Language labels. Current options are 'en' for English and 'es' for Spanish.

Value

Graphical device.

Author(s)

Guillermo Vinue

Examples

## Not run: 
get_roster_age_profile(acb_age_profile_data_2526, "Valencia Basket", "es")

## End(Not run)


BAwiR documentation built on Feb. 27, 2026, 5:07 p.m.