metrics_player_zone: ACB players 2024-2025

metrics_player_zoneR Documentation

ACB players 2024-2025

Description

Metrics (total shots, field goal percentages and points per shot) at some of the court zones for some of the 30 players contained in the data frame acb_players_2425.

Usage

metrics_player_zone

Format

Data frame with 8 rows and 5 columns.

https://www.acb.com/


BAwiR documentation built on Feb. 27, 2026, 5:07 p.m.