Learn R Programming

BAwiR (version 1.4.2)

acb_sticker_data_2526: ACB sticker data, 2025-2026

Description

This data frame contains an example of the usage and context statistics for the Real Madrid player Alberto Abalde to illustrate the creation of the sticker plot.

Usage

acb_sticker_data_2526

Arguments

Format

Data frame with 11 rows and 9 columns.