| acb_usage_act_data_2526 | R Documentation |
Sample of possessions played and ended for a game from the ACB 2025-2026 season and the particular number of actions used by the player to end the possession.
acb_usage_act_data_2526
Data frame with 75 rows and 8 columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.