View source: R/do_divide_court_zones.R
| do_divide_court_zones | R Documentation |
Divide the basketball court into 10 zones.
do_divide_court_zones(data_shots)
data_shots |
Shooting data frame. |
The shooting data frame with a new column called "location" indicating the zone from which each shot was taken.
Guillermo Vinue
## Not run:
do_divide_court_zones(acb_shooting_data_2425)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.