Learn R Programming

BAwiR (version 1.4)

do_divide_court_zones: Zones of the basketball court

Description

Divide the basketball court into 10 zones.

Usage

do_divide_court_zones(data_shots)

Value

The shooting data frame with a new column called "location" indicating the zone from which each shot was taken.

Arguments

data_shots

Shooting data frame.

Author

Guillermo Vinue

Examples

Run this code
if (FALSE) {
do_divide_court_zones(acb_shooting_data_2425)
}

Run the code above in your browser using DataLab