powered by
Divide the basketball court into 10 zones.
do_divide_court_zones(data_shots)
The shooting data frame with a new column called "location" indicating the zone from which each shot was taken.
Shooting data frame.
Guillermo Vinue
if (FALSE) { do_divide_court_zones(acb_shooting_data_2425) }
Run the code above in your browser using DataLab