View source: R/do_time_out_success_altern.R
| do_time_out_success_altern | R Documentation |
This is an alternative to do_time_out_success from season 2025-2026
because to my best of knowledge the timeouts are not directly collected from
web scraping and I have to check manually when they were called.
do_time_out_success_altern(data, day_num, game_code, team_sel, data_to_list, verbose)
data |
Prepared data from a given game. |
day_num |
Day number. |
game_code |
Game code. |
team_sel |
One of the teams' names involved in the game. |
data_to_list |
List with all the timeouts called from all coaches. |
verbose |
Logical. Decide if information of the computations must be provided or not. |
Data frame. This is the meaning of the columns:
day: Day number. game_code: Game code. team: Name of the corresponding team and coach. times_out_requested: Number of timeouts requested in the game. times_out_successful: Number of timeouts that resulted in scoring. times_out_successful_perc: Percentage of successful timeouts. points_scored: Total of points achieved after the timeouts.
Guillermo Vinue
do_time_out_success
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.