Learn R Programming

BAwiR (version 1.4)

do_violin_box_plots: Plots of data distributions

Description

Create violin plots and boxplots to analyze the distribution of the two-point, three-point and total shots. Violin plots show the distribution shape, while boxplots give a compact statistical summary.

Usage

do_violin_box_plots(data_shots, data_players)

Value

A plot.

Arguments

data_shots

Shooting data frame.

data_players

Players' identifiers data frame.

Author

Guillermo Vinue

Examples

Run this code
if (FALSE) {
df0 <- do_divide_court_zones(acb_shooting_data_2425)

df1 <- do_filter_data(df0, "2024-2025", "", "", "", "", "")

do_violin_box_plots(df1, acb_players_2425)
}

Run the code above in your browser using DataLab