powered by
Create violin plots and boxplots to analyze the distribution of the two-point, three-point and total shots. Violin plots show the distribution shape, while boxplots give a compact statistical summary.
do_violin_box_plots(data_shots, data_players)
A plot.
Shooting data frame.
Players' identifiers data frame.
Guillermo Vinue
if (FALSE) { df0 <- do_divide_court_zones(acb_shooting_data_2425) df1 <- do_filter_data(df0, "2024-2025", "", "", "", "", "") do_violin_box_plots(df1, acb_players_2425) }
Run the code above in your browser using DataLab