View source: R/do_volume_threes.R
| do_volume_threes | R Documentation |
This function computes the three-point shots volume, both in offense in defense. This volume is defined as the percentage of three-point shots attempted with respect to the total field-goal attempts.
do_volume_threes(df)
df |
Data frame with the games and the players info. |
A data frame with the volume statistics.
Guillermo Vinue
library(dplyr)
df0 <- do_join_games_bio("ACB", acb_games_1718, acb_players_1718)
df1 <- df0 %>% rename(game_code = Game)
data_volume <- do_volume_threes(df1)
data_volume$data_volume_threes
data_volume$data_volume_threes_comp
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.