View source: R/get_donut_usage.R
| get_donut_usage | R Documentation |
This function creates a donut chart that displays the percentage of possessions that each player of a team ends while being on the court.
get_donut_usage(data_usage, team_sel, size_play, size_perc)
data_usage |
Data frame with the number of possessions that each player played and the number that he ended. |
team_sel |
String with the team's full name. |
size_play |
Size of the players' labels. |
size_perc |
Size of the percentages labels. |
Donut charts are an alternative for pie charts, which have a hole in the middle, making them cleaner to read than pie charts.
A donut chart.
Guillermo Vinue with the help of ChatGPT.
get_donut_usage_action
## Not run:
get_donut_usage(acb_usage_data_2526, "Valencia Basket", 3, 4)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.