View source: R/get_net_rtg_on_off.R
| get_net_rtg_on_off | R Documentation |
The Net Rating On/Off measures a team's net rating when a specific player is on the court versus when they are on the bench. It highlights the player's impact by comparing the team's efficiency both in offense and defense. A positive differential indicates a positive, higher-impact player.
get_net_rtg_on_off(data_combs, team_name, type_lineup, type_period, type_opponent,
filter_players, language, asp_ratio = 1)
data_combs |
Data frame with all the combinations of lineups. |
team_name |
Name of the team. |
type_lineup |
Type of lineups to analyze. Options are 'quintet', 'quartet', 'trio', 'duo' and 'single'. |
type_period |
Period of interest. Options are xC, where x starts from 1. Common periods are from 1 to 4. Overtimes are labeled with the next numbers, such as 5C for the first overtime and 6C for the second one. Nothing to do if NULL. |
type_opponent |
Name of the opponent teams. Nothing to do if NULL. |
filter_players |
String with the players' names to filter. Nothing to do if NULL. |
language |
Language of the legends and titles. |
asp_ratio |
Aspect ratio of the plot. Default 1. |
Net Rating: difference between Offensive Rating and Defensive Rating.
On-Court Rating: team's net rating while the player is in the game.
Off-Court Rating: team's net rating while the player is on the bench.
On/Off Differential: difference between the on-court and off-court net ratings, which gives a first idea of how much better/worse the team performs with that player.
A plot with the players' net ratings and differentials.
Guillermo Vinue
do_possession_stats_lineup
## Not run:
get_net_rtg_on_off(acb_combs, "Unicaja", "single", NULL, NULL, NULL, "Spanish")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.