View source: R/get_roster_age_profile.R
| get_roster_age_profile | R Documentation |
For the players of the same team, show their age at time of joining the team, their current year and how many years they have spent in the team.
get_roster_age_profile(data_age_team, team_sel, language)
data_age_team |
Data frame with the team's age profile. |
team_sel |
Team. |
language |
Language labels. Current options are 'en' for English and 'es' for Spanish. |
Graphical device.
Guillermo Vinue
## Not run:
get_roster_age_profile(acb_age_profile_data_2526, "Valencia Basket", "es")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.