Learn R Programming

BAwiR (version 1.5)

get_roster_age_profile: Roster age profile

Description

For the players of the same team, show their age at time of joining the team, their current year and how many years they have spent in the team.

Usage

get_roster_age_profile(data_age_team, team_sel, language)

Value

Graphical device.

Arguments

data_age_team

Data frame with the team's age profile.

team_sel

Team.

language

Language labels. Current options are 'en' for English and 'es' for Spanish.

Author

Guillermo Vinue

Examples

Run this code
if (FALSE) {
get_roster_age_profile(acb_age_profile_data_2526, "Valencia Basket", "es")
}

Run the code above in your browser using DataLab