powered by
For the players of the same team, show their age at time of joining the team, their current year and how many years they have spent in the team.
get_roster_age_profile(data_age_team, team_sel, language)
Graphical device.
Data frame with the team's age profile.
Team.
Language labels. Current options are 'en' for English and 'es' for Spanish.
Guillermo Vinue
if (FALSE) { get_roster_age_profile(acb_age_profile_data_2526, "Valencia Basket", "es") }
Run the code above in your browser using DataLab